Introduction — nes 1.1.8 documentation

# Introduction

## About

NES (NetCDF for Earth Science) is the Python I/O library used by SNES, the framework that implements the data post-processing pipelines at the Earth Sciences department, to read and write netCDF files.

## How to clone

Use the following command to get a copy of the repository:

    pip install NES

## How to run

For running NES, please follow the instruction in the wiki.